@@ -117,12 +117,12 @@ summary.sars <- function(object, ...){
                     function(x){x$observed_shape}, FUN.VALUE = character(1))
     #a warning produces a long shape value sometimes: "observed shape 
     #algorithm failed: observed shape ..". So change these cases to sigmoid
-    shape_check <- vapply(df$Shape, FUN = function(x){grepl("failed", x)},
-                          FUN.VALUE = logical(1))
-    if (any(shape_check)){
-      wsc <- which(shape_check)
-      df$Shape[wsc] <- "sigmoid"
-    }
+    #shape_check <- vapply(df$Shape, FUN = function(x){grepl("failed", x)},
+    #                      FUN.VALUE = logical(1))
+    #if (any(shape_check)){
+      #wsc <- which(shape_check)
+      #df$Shape[wsc] <- "sigmoid"
+   # }
     df$Asymptote <- vapply(object$details$fits,
                            function(x){x$asymptote}, FUN.VALUE = logical(1))
     df <- df[order(-df$Weight),]
