@@ -1,16 +1,14 @@
 #' Fit the Monod model
 
 #' @description Fit the Monod model to SAR data.
-#' @usage sar_monod(data, start = NULL, grid_start = NULL, normaTest =  'lillie',
-              
+#' @usage sar_monod(data, start = NULL, grid_start = FALSE, grid_n = NULL, normaTest = 'lillie',
 #'   homoTest = 'cor.fitted')
 #' @param data A dataset in the form of a dataframe with two columns: 
 #'   the first with island/site areas, and the second with the species richness
 #'   of each island/site.
 #' @param start NULL or custom parameter start values for the optimisation algorithm.
-#' @param grid_start NULL or the number of points sampled in the model parameter space
-#'   or FALSE to prevent any grid start after a fail in initial optimization
-#'   to run a grid search.
+#' @param grid_start Logical argument specifying whether a grid search procedure should be implemented to test multiple starting parameter values. The default is set to FALSE, but for certain models (e.g. Gompertz, Chapman Richards), we advice using it to ensure an optimal fit.
+#' @param grid_n If \code{grid_start = TRUE}, the number of points sampled in the model parameter space.
 #' @param normaTest The test used to test the normality of the residuals of the
 #'   model. Can be any of 'lillie' (Lilliefors Kolmogorov-Smirnov test; the
 #'   default), 'shapiro' (Shapiro-Wilk test of normality), 'kolmo'
@@ -22,8 +20,10 @@
 #' @details The model is fitted using non-linear regression. The model parameters are estimated
 #'   by minimizing the residual sum of squares with an unconstrained Nelder-Mead optimization algorithm
 #'   and the \code{\link{optim}} function. To avoid numerical problems and speed up the convergence process,
-#'   the starting values used to run the optimization algorithm are carefully chosen, or custom values can be provided
-#'   using the argument \code{start}. The fitting process also determines the observed shape of the model fit,
+#'   the starting values used to run the optimization algorithm are carefully chosen. However, if this does
+#' not work, custom values can be provided (using the \code{start} argument), or a more comprehensive search
+#'   can be undertaken using the \code{grid_start} argument. See the vignette for more information.
+#'   The fitting process also determines the observed shape of the model fit,
 #'   and whether or not the observed fit is asymptotic (see Triantis et al. 2012 for further details).
 
 #'   Model validation is undertaken by assessing the normality (\code{normaTest}) and homogeneity (\code{homoTest})
@@ -69,12 +69,17 @@
 #' plot(fit)
 #' @export
 
-sar_monod <- function(data, start = NULL, grid_start = NULL, 
-normaTest =  "lillie", homoTest = "cor.fitted"){
+sar_monod <- function(data, start = NULL, grid_start = FALSE, 
+grid_n = NULL, normaTest =  "lillie", homoTest = "cor.fitted"){
 if (!(is.matrix(data) | is.data.frame(data)))  
 stop('data must be a matrix or dataframe')
 if (is.matrix(data)) data <- as.data.frame(data)
 if (anyNA(data)) stop('NAs present in data')
+if (!is.logical(grid_start)) stop('grid_start should be logical')
+if (grid_start){
+  if (!is.numeric(grid_n))
+  stop('grid_n should be numeric if grid_start == TRUE')
+  }
 data <- data[order(data[,1]),]
 colnames(data) <- c('A','S')
 #check for all equal richness values (particuarly zeros)
@@ -107,9 +112,8 @@ model <- list(
 
 model <- compmod(model)
 fit <- get_fit(model = model, data = data, start = start,  
-grid_start = grid_start, algo = 'Nelder-Mead', 
-       
-normaTest =  normaTest, homoTest = homoTest, verb = TRUE)
+grid_start = grid_start, grid_n = grid_n, algo = 'Nelder-Mead', 
+       normaTest =  normaTest, homoTest = homoTest, verb = TRUE)
 if(is.na(fit$value)){
   return(list(value = NA))
 }else{ 
